@@ -113,7 +113,7 @@ class CentralReachCore(SitesCore):
             if self.browser.does_page_contain_element(xpath):
                 try:
                     is_success = self.browser.find_element(xpath).is_displayed()
-                except SeleniumLibrary.errors.ElementNotFound:
+                except Exception:
                     time.sleep(1)
 
             if not is_success:
@@ -216,6 +216,11 @@ class CentralReachCore(SitesCore):
             )
 
     def is_no_results(self) -> bool:
+        self.wait_element(
+            '//div[text()="No results matched your keywords, filters, or date range" and not(@style="display: none;")]',
+            5,
+            False,
+        )
         if self.browser.does_page_contain_element(
             '//div[text()="No results matched your keywords, filters, or date range" and not(@style="display: none;")]'
         ):
