@@ -9,13 +9,14 @@ class SalesforceCore(SitesCore):
     """
     Salesforce object. Please Inheritance it.
     """
+
     def get_mfa_code(self) -> str:
         """
         Please, modify this function in your code
         :return:
         """
 
-        return ''
+        return ""
 
     def get_email_code(self) -> str:
         """
@@ -23,7 +24,7 @@ class SalesforceCore(SitesCore):
         :return:
         """
 
-        return ''
+        return ""
 
     def login_to_site(self) -> bool:
         self.is_site_available = False
@@ -48,15 +49,9 @@ class SalesforceCore(SitesCore):
 
                 self.wait_element('//input[@id="tc"]', timeout=5, is_need_screenshot=False)
                 if self.does_element_displayed('//input[@id="tc"]'):
-                    self.browser.input_text(
-                        '//input[@id="tc"]',
-                        self.get_mfa_code()
-                    )
+                    self.browser.input_text('//input[@id="tc"]', self.get_mfa_code())
                 elif self.does_element_displayed('//input[@id="emc"]'):
-                    self.browser.input_text(
-                        '//input[@id="emc"]',
-                        self.get_email_code()
-                    )
+                    self.browser.input_text('//input[@id="emc"]', self.get_email_code())
 
                 if self.does_element_displayed('//input[@id="save"]'):
                     self.browser.click_element('//input[@id="save"]')
@@ -67,9 +62,9 @@ class SalesforceCore(SitesCore):
                     self.is_site_available = True
                     return True
             except Exception as ex:
-                logging.error(f'Login failed. Attempt {i}')
+                logging.error(f"Login failed. Attempt {i}")
                 logging.error(str(ex))
                 traceback.print_exc()
-                self.browser.capture_page_screenshot(os.path.join(self.output_folder, f'Login_failed_Attempt_{i}.png'))
+                self.browser.capture_page_screenshot(os.path.join(self.output_folder, f"Login_failed_Attempt_{i}.png"))
                 self.browser.close_browser()
         return False
